flatland package
================

Submodules
----------

flatland.cli module
-------------------

.. automodule:: flatland.cli
    :members:
    :undoc-members:
    :show-inheritance:

flatland.flatland module
------------------------

.. automodule:: flatland.flatland
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: flatland
    :members:
    :undoc-members:
    :show-inheritance:
